tuplettools.get_first_tuplet_in_improper_parentage_of_component
===============================================================

.. autofunction:: abjad.tools.tuplettools.get_first_tuplet_in_improper_parentage_of_component.get_first_tuplet_in_improper_parentage_of_component
